.. currentmodule:: index_calculator

"""""""""""""
API reference
"""""""""""""

This page provides an auto-generated summary of the index_calculator API.

Top-level classes for calculating climate indices
=================================================

.. autosummary::
   :toctree: generated/

   preprocessing

.. autosummary::
   :toctree: generated/

   processing

.. autosummary::
   :toctree: generated/

   postprocessing

.. autosummary::
   :toctree: generated/

   outputwriter

.. autosummary::
   :toctree: generated/

   index_calculator
